import setuptools


setuptools.setup(
    name="lxlog",
    version="0.3.0",
    author="selvaguru",
    author_email="your_email@example.com",
    description="A package for analyzing system log files",
    long_description_content_type="text/markdown",
    url="https://selvaguru-s.web.app",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)

